:orphan:

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

FileBrowser 3.14 Release Notes
==============================

FileBrowser 3.14 is compatible with Django 3.2 as well as Grappelli 2.15.

Updates
-------

* Compatibility with Django 3.2 and Grappelli 2.15

Update from FileBrowser 3.13.x
------------------------------

* Update Django to 3.2 and check https://docs.djangoproject.com/en/3.2/releases/3.2/
* Update Grappelli to 2.15.x
* Update FileBrowser to 3.14.x
